@@ -13,10 +13,14 @@ import numpy as np
 from astropy import units as u
 from astropy.coordinates.representation import (CartesianRepresentation,
                                                 UnitSphericalRepresentation,
-                                                SphericalRepresentation)
+                                                SphericalRepresentation,
+                                                CylindricalRepresentation)
+
 from astropy.coordinates.baseframe import (BaseCoordinateFrame,
                                            RepresentationMapping)
-from astropy.coordinates import Attribute, CoordinateAttribute, ConvertError
+
+from astropy.coordinates import Attribute, ConvertError
+from astropy.tests.helper import quantity_allclose
 
 from sunpy import sun
 from .representation import (SphericalWrap180Representation, UnitSphericalWrap180Representation)
@@ -63,16 +67,16 @@ class HeliographicStonyhurst(BaseCoordinateFrame):
     >>> sc = SkyCoord(1*u.deg, 1*u.deg, 2*u.km,
     ...               frame="heliographic_stonyhurst",
     ...               obstime="2010/01/01T00:00:45")
-    >>> sc
-    <SkyCoord (HeliographicStonyhurst): obstime=2010-01-01 00:00:45,
-    lon=1.0 deg, lat=1.0 deg, rad=2.0 km>
-    >>> sc.frame
-    <HeliographicStonyhurst Coordinate: obstime=2010-01-01 00:00:45,
-    lon=1.0 deg, lat=1.0 deg, rad=2.0 km>
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (HeliographicStonyhurst: obstime=2010-01-01 00:00:45): (lon, lat, radius) in (deg, deg, km)
+        ( 1.,  1.,  2.)>
+    >>> sc.frame # doctest: +FLOAT_CMP
+    <HeliographicStonyhurst Coordinate (obstime=2010-01-01 00:00:45): (lon, lat, radius) in (deg, deg, km)
+        ( 1.,  1.,  2.)>
     >>> sc = SkyCoord(HeliographicStonyhurst(-10*u.deg, 2*u.deg))
-    >>> sc
-    <SkyCoord (HeliographicStonyhurst): obstime=None, lon=-10.0 deg,
-    lat=2.0 deg, rad=695508.0 km>
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (HeliographicStonyhurst: obstime=None): (lon, lat, radius) in (deg, deg, km)
+        (-10.,  2.,  695508.)>
 
     Notes
     -----
@@ -100,6 +104,10 @@ class HeliographicStonyhurst(BaseCoordinateFrame):
     def __init__(self, *args, **kwargs):
         _rep_kwarg = kwargs.get('representation', None)
 
+        if ('radius' in kwargs and kwargs['radius'].unit is u.one and
+                quantity_allclose(kwargs['radius'], 1*u.one)):
+            kwargs['radius'] = RSUN_METERS.to(u.km)
+
         super(HeliographicStonyhurst, self).__init__(*args, **kwargs)
 
         # Make 3D if specified as 2D
@@ -113,7 +121,7 @@ class HeliographicStonyhurst(BaseCoordinateFrame):
             elif isinstance(self._data, UnitSphericalRepresentation):
                 distance = RSUN_METERS.to(u.km)
 
-            if distance:
+            if distance is not None:
                 self._data = self.default_representation(lat=self._data.lat,
                                                          lon=self._data.lon,
                                                          distance=distance)
@@ -121,11 +129,17 @@ class HeliographicStonyhurst(BaseCoordinateFrame):
 
 class HeliographicCarrington(HeliographicStonyhurst):
     """
-    A coordinate or frame in the Carrington Heliographic
-    system.
-    This frame differs from the Stonyhurst version in the
-    definition of the longitude, which is defined using
-    an offset which is a time-dependent scalar value.
+    A coordinate or frame in the Carrington Heliographic system.
+
+    - The origin is the centre of the Sun
+    - The z-axis is aligned with the Sun's north pole
+    - The x and y axes rotate with a period of 25.38 days. The line of zero
+      longitude passed through the disk centre as seen from Earth at
+      21:36 on 9th Nov 1853.
+
+    This frame differs from the Stonyhurst version in the definition of the
+    longitude, which is defined using the time-dependant offset described
+    above.
 
     Parameters
     ----------
@@ -139,8 +153,7 @@ class HeliographicCarrington(HeliographicStonyhurst):
         The latitude for this object (``lon`` must also be given and
         ``representation`` must be None).
     radius: `astropy.units.Quantity` object, optional, must be keyword.
-        This quantity holds the radial distance. If not specified, it is, by
-        default, the solar radius. Optional, must be keyword.
+        This quantity holds the radial distance. Defaults to the solar radius.
     obstime: SunPy Time
         The date and time of the observation, used to convert to heliographic
         carrington coordinates.
@@ -153,15 +166,15 @@ class HeliographicCarrington(HeliographicStonyhurst):
     >>> sc = SkyCoord(1*u.deg, 2*u.deg, 3*u.km,
     ...               frame="heliographic_carrington",
     ...               obstime="2010/01/01T00:00:30")
-    >>> sc
-    <SkyCoord (HelioGraphicCarrington): obstime=2010-01-01 00:00:30,
-    lon=1.0 deg, lat=2.0 deg, rad=3.0 km>
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (HeliographicCarrington: obstime=2010-01-01 00:00:30): (lon, lat, radius) in (deg, deg, km)
+        ( 1.,  2.,  3.)>
+
     >>> sc = SkyCoord([1,2,3]*u.deg, [4,5,6]*u.deg, [5,6,7]*u.km,
-    obstime="2010/01/01T00:00:45", frame="heliographic_carrington")
-    >>> sc
-    <SkyCoord (HelioGraphicCarrington): obstime=2010-01-01 00:00:45,
-    (lon, lat, rad) in (deg, deg, km)
-        [(1.0, 4.0, 5.0), (2.0, 5.0, 6.0), (3.0, 6.0, 7.0)]>
+    ...               obstime="2010/01/01T00:00:45", frame="heliographic_carrington")
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (HeliographicCarrington: obstime=2010-01-01 00:00:45): (lon, lat, radius) in (deg, deg, km)
+        [( 1.,  4.,  5.), ( 2.,  5.,  6.), ( 3.,  6.,  7.)]>
     """
 
     name = "heliographic_carrington"
@@ -186,11 +199,16 @@ class HeliographicCarrington(HeliographicStonyhurst):
 class Heliocentric(BaseCoordinateFrame):
     """
     A coordinate or frame in the Heliocentric system.
-    This frame may either be specified in Cartesian
-    or cylindrical representation.
-    Cylindrical representation replaces (x, y) with
-    (rho, psi) where rho is the impact parameter and
-    psi is the position angle in degrees.
+
+    - The origin is the centre of the Sun
+    - The z-axis points from the centre of the Sun to the observer.
+    - The y-axis is perpendicular to the z-axis, and lies in the plane that
+      contains the z-axis and the solar rotation axis, pointing towards the
+      Sun's north pole.
+
+    This frame may either be specified in Cartesian or cylindrical
+    representation. Cylindrical representation replaces (x, y) with (rho, psi)
+    where rho is the impact parameter and psi is the position angle in degrees.
 
     Parameters
     ----------
@@ -204,28 +222,33 @@ class Heliocentric(BaseCoordinateFrame):
         Y-axis coordinate, optional, must be keyword.
     z: `Quantity` object. Shared by both representations.
         Z-axis coordinate, optional, must be keyword.
-    observer: `~sunpy.coordinates.frames.HeliographicStonyhurst`
-        The coordinate of the observer in the solar system.
+    observer: `~sunpy.coordinates.frames.HeliographicStonyhurst`, optional
+        The coordinate of the observer in the solar system. Defaults to the
+        Earth.
     obstime: SunPy Time
         The date and time of the observation, used to convert to heliographic
         carrington coordinates.
 
     Examples
     --------
+
     >>> from astropy.coordinates import SkyCoord, CartesianRepresentation
     >>> import sunpy.coordinates
     >>> import astropy.units as u
+
     >>> sc = SkyCoord(CartesianRepresentation(10*u.km, 1*u.km, 2*u.km),
     ...               obstime="2011/01/05T00:00:50", frame="heliocentric")
-    >>> sc
-    <SkyCoord (HelioCentric): obstime=2011-01-05 00:00:50, D0=149597870.7 km,
-    x=10.0 km, y=1.0 km, z=2.0 km>
-    >>> sc = SkyCoord([1,2]*u.km, [3,4]*u.m, [5,6]*u.cm, frame="heliocentric",
-    obstime="2011/01/01T00:00:54")
-    >>> sc
-    <SkyCoord (HelioCentric): obstime=2011-01-01 00:00:54, D0=149597870.7 km,
-    (x, y, z) in (km, m, cm)
-        [(1.0, 3.0, 5.0), (2.0, 4.0, 6.0)]>
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (Heliocentric: obstime=2011-01-05 00:00:50, observer=<HeliographicStonyhurst Coordinate (obstime=2011-01-05 00:00:50): (lon, lat, radius) in (deg, deg, AU)
+        ( 0., -3.43939103,  0.98334411)>): (x, y, z) in km
+        ( 10.,  1.,  2.)>
+
+    >>> sc = SkyCoord([1,2]*u.km, [3,4]*u.m, [5,6]*u.cm, frame="heliocentric", obstime="2011/01/01T00:00:54")
+
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (Heliocentric: obstime=2011-01-01 00:00:54, observer=<HeliographicStonyhurst Coordinate (obstime=2011-01-01 00:00:54): (lon, lat, radius) in (deg, deg, AU)
+        ( 0., -2.97725356,  0.98335586)>): (x, y, z) in (km, m, cm)
+        [( 1.,  3.,  5.), ( 2.,  4.,  6.)]>
     """
 
     default_representation = CartesianRepresentation
@@ -274,14 +297,15 @@ class Helioprojective(BaseCoordinateFrame):
     >>> import astropy.units as u
     >>> sc = SkyCoord(0*u.deg, 0*u.deg, 5*u.km, obstime="2010/01/01T00:00:00",
     ...               frame="helioprojective")
-    >>> sc
-    <SkyCoord (HelioProjective): obstime=2010-01-01 00:00:00, D0=149597870.7 km
-    , Tx=0.0 arcsec, Ty=0.0 arcsec, distance=5.0 km>
-    >>> sc = SkyCoord(0*u.deg, 0*u.deg, obstime="2010/01/01T00:00:00",
-    frame="helioprojective")
-    >>> sc
-    <SkyCoord (HelioProjective): obstime=2010-01-01 00:00:00, D0=149597870.7 km
-    , Tx=0.0 arcsec, Ty=0.0 arcsec, distance=149597870.7 km>
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (Helioprojective: obstime=2010-01-01 00:00:00, rsun=695508.0 km, observer=<HeliographicStonyhurst Coordinate (obstime=2010-01-01 00:00:00): (lon, lat, radius) in (deg, deg, AU)
+        ( 0., -3.00724817,  0.98330294)>): (Tx, Ty, distance) in (arcsec, arcsec, km)
+        ( 0.,  0.,  5.)>
+    >>> sc = SkyCoord(0*u.deg, 0*u.deg, obstime="2010/01/01T00:00:00", frame="helioprojective")
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (Helioprojective: obstime=2010-01-01 00:00:00, rsun=695508.0 km, observer=<HeliographicStonyhurst Coordinate (obstime=2010-01-01 00:00:00): (lon, lat, radius) in (deg, deg, AU)
+        ( 0., -3.00724817,  0.98330294)>): (Tx, Ty) in arcsec
+        ( 0.,  0.)>
     """
 
     default_representation = SphericalWrap180Representation
@@ -290,12 +314,12 @@ class Helioprojective(BaseCoordinateFrame):
         'spherical': [
             RepresentationMapping('lon', 'Tx', u.arcsec),
             RepresentationMapping('lat', 'Ty', u.arcsec),
-            RepresentationMapping('distance', 'distance', u.km)
+            RepresentationMapping('distance', 'distance', None)
         ],
         'sphericalwrap180': [
             RepresentationMapping('lon', 'Tx', u.arcsec),
             RepresentationMapping('lat', 'Ty', u.arcsec),
-            RepresentationMapping('distance', 'distance', u.km)
+            RepresentationMapping('distance', 'distance', None)
         ],
         'unitspherical': [
             RepresentationMapping('lon', 'Tx', u.arcsec),
@@ -346,7 +370,8 @@ class Helioprojective(BaseCoordinateFrame):
             now with a third coordinate.
         """
         # Skip if we already are 3D
-        if isinstance(self._data, SphericalRepresentation):
+        if (isinstance(self._data, SphericalRepresentation) and
+                not (self.distance.unit is u.one and quantity_allclose(self.distance, 1*u.one))):
             return self
 
         if not isinstance(self.observer, BaseCoordinateFrame):
